@@ -21,7 +21,6 @@
  * SOFTWARE.
  */
 #![no_std]
-#![feature(convert, core_str_ext, no_std)]
 
 use core::cmp::Ordering::{self,Less,Greater,Equal};
 use core::marker::PhantomData;
@@ -35,7 +34,7 @@ use core::slice;
 #[cfg(not(any(target_arch = "arm", target_arch = "aarch64")))]
 #[allow(non_camel_case_types)]
 pub type c_char = i8;
-#[cfg(any(target_arch = "arm", target_arch = "aarch64"))]
+#[cfg(any(target_arch = "arm", target_arch = "aarch64", target_arch = "powerpc"))]
 #[allow(non_camel_case_types)]
 pub type c_char = u8;
 
